==> httpcomponents-core_4.0.1.orig.tar.gz: httpcomponents-core-4.0.1/httpcore-nio/src/test/java/org/apache/http/mockup/SimpleEventListener.java <==
/*
 * $HeadURL: https://svn.apache.org/repos/asf/httpcomponents/httpcore/tags/4.0.1/httpcore-nio/src/test/java/org/apache/http/mockup/SimpleEventListener.java $
 * $Revision: 575207 $
 * $Date: 2007-09-13 09:57:05 +0200 (Thu, 13 Sep 2007) $
 *
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.http.mockup;

import java.io.IOException;

import org.apache.http.HttpException;
import org.apache.http.nio.NHttpConnection;
import org.apache.http.nio.protocol.EventListener;

public class SimpleEventListener implements EventListener {

    public SimpleEventListener() {
        super();
    }
    
    public void connectionOpen(final NHttpConnection conn) {
    }

    public void connectionTimeout(final NHttpConnection conn) {
    }

    public void connectionClosed(final NHttpConnection conn) {
    }

    public void fatalIOException(final IOException ex, final NHttpConnection conn) {
        ex.printStackTrace();
    }

    public void fatalProtocolException(final HttpException ex, NHttpConnection conn) {
        ex.printStackTrace();
    }
        
}

==> httpcomponents-core_4.1.4.orig.tar.gz: httpcomponents-core-4.1.4/httpcore-nio/src/test/java/org/apache/http/mockup/SimpleEventListener.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.http.mockup;

import java.io.IOException;

import org.apache.http.HttpException;
import org.apache.http.nio.NHttpConnection;
import org.apache.http.nio.protocol.EventListener;

public class SimpleEventListener implements EventListener {

    public SimpleEventListener() {
        super();
    }

    public void connectionOpen(final NHttpConnection conn) {
    }

    public void connectionTimeout(final NHttpConnection conn) {
        System.out.println("Connection timed out");
    }

    public void connectionClosed(final NHttpConnection conn) {
    }

    public void fatalIOException(final IOException ex, final NHttpConnection conn) {
        ex.printStackTrace(System.out);
    }

    public void fatalProtocolException(final HttpException ex, final NHttpConnection conn) {
        ex.printStackTrace(System.out);
    }

}
